Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(159)

Unified Diff: components/data_reduction_proxy/core/browser/data_reduction_proxy_service.h

Issue 1546143002: Switch to standard integer types in components/, part 1 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/data_reduction_proxy/core/browser/data_reduction_proxy_service.h
diff --git a/components/data_reduction_proxy/core/browser/data_reduction_proxy_service.h b/components/data_reduction_proxy/core/browser/data_reduction_proxy_service.h
index f1e654aa5dd9edc61364561bab918a4b450c66fa..4cf18f6cb40c19e218119bb8f8e8affe5ff48d4e 100644
--- a/components/data_reduction_proxy/core/browser/data_reduction_proxy_service.h
+++ b/components/data_reduction_proxy/core/browser/data_reduction_proxy_service.h
@@ -5,6 +5,8 @@
#ifndef COMPONENTS_DATA_REDUCTION_PROXY_CORE_BROWSER_DATA_REDUCTION_PROXY_SERVICE_H_
#define COMPONENTS_DATA_REDUCTION_PROXY_CORE_BROWSER_DATA_REDUCTION_PROXY_SERVICE_H_
+#include <stdint.h>
+
#include <string>
#include "base/callback.h"
@@ -83,8 +85,8 @@ class DataReductionProxyService
const base::TimeDelta& commit_delay);
// Records daily data savings statistics in |compression_stats_|.
- void UpdateContentLengths(int64 data_used,
- int64 original_size,
+ void UpdateContentLengths(int64_t data_used,
+ int64_t original_size,
bool data_reduction_proxy_enabled,
DataReductionProxyRequestType request_type,
const std::string& data_usage_host,
@@ -96,7 +98,7 @@ class DataReductionProxyService
void AddEventAndSecureProxyCheckState(scoped_ptr<base::Value> event,
SecureProxyCheckState state) override;
void AddAndSetLastBypassEvent(scoped_ptr<base::Value> event,
- int64 expiration_ticks) override;
+ int64_t expiration_ticks) override;
// Records whether the Data Reduction Proxy is unreachable or not.
void SetUnreachable(bool unreachable);
@@ -111,8 +113,8 @@ class DataReductionProxyService
// Initializes the Lo-Fi implicit opt out prefs.
void InitializeLoFiPrefs();
- // Stores an int64 value in |prefs_|.
- void SetInt64Pref(const std::string& pref_path, int64 value);
+ // Stores an int64_t value in |prefs_|.
+ void SetInt64Pref(const std::string& pref_path, int64_t value);
// Stores a string value in |prefs_|.
void SetStringPref(const std::string& pref_path, const std::string& value);

Powered by Google App Engine
This is Rietveld 408576698